@@ -58,11 +58,25 @@ sub get {
     return \%data;
 }
 
-sub set {
+sub set     { return &_store(shift, 'set', @_); }
+sub add     { return &_store(shift, 'add', @_); }
+sub replace { return &_store(shift, 'replace', @_); }
+sub append  { return &_modify(shift, 'append',  @_); }
+sub prepend { return &_modify(shift, 'prepend', @_); }
+
+sub _modify {
+    my $self  = shift;
+    my ($cmd, $key, $value) = @_;
+    return $self->_store($cmd, $key, $value);
+}
+
+sub _store {
     my $self   = shift;
+    my $cmd    = shift;
     my $key    = shift;
     my $value  = shift;
     my %option = @_;
+
     my $flags  = $option{flags}  || 0;
     my $expire = $option{expire} || 0;
     my $bytes  = sub {
@@ -71,11 +85,11 @@ sub set {
     }->();
 
     my $socket = $self->{socket};
-    print $socket "set $key $flags $expire $bytes\r\n";
+    print $socket "$cmd $key $flags $expire $bytes\r\n";
     print $socket "$value\r\n";
     my $response = $self->_readline;
     if ($response !~ m/^STORED/) {
-        warn "Failed to set '$key' with '$value'";
+        debug qq{Failed to $cmd data as ($key, $value)};
         return;
     }
     return 1;
