@@ -6,7 +6,7 @@ use 5.008_001;
 
 use App::Memcached::CLI::Util ':all';
 
-use version; our $VERSION = 'v0.6.0';
+use version; our $VERSION = 'v0.6.1';
 
 my $DISPLAY_DATA_LENGTH = 320;
 
@@ -39,7 +39,10 @@ sub save {
         flags  => $self->{flags},
         expire => $self->{expire},
     );
-    my $ret = $ds->set($self->{key}, $self->{value}, %option);
+
+    my $command = $opt{command} || 'set';
+    my $ret = $ds->$command($self->{key}, $self->{value}, %option);
+
     return $ret;
 }
 
