@@ -13,10 +13,11 @@ use Term::ReadLine;
 
 use App::Memcached::CLI;
 use App::Memcached::CLI::DataSource;
+use App::Memcached::CLI::Help;
 use App::Memcached::CLI::Item;
 use App::Memcached::CLI::Util ':all';
 
-use version; our $VERSION = 'v0.6.0';
+use version; our $VERSION = 'v0.6.1';
 
 my $PROGRAM = basename $0;
 
@@ -32,6 +33,10 @@ my %COMMAND2ALIASES = (
     detail     => [],
     get        => [],
     set        => [],
+    add        => [],
+    replace    => [],
+    append     => [],
+    prepend    => [],
     delete     => [],
     flush_all  => [qw(flush)],
 );
@@ -165,114 +170,8 @@ sub help {
     my $self    = shift;
     my $command = shift || q{};
 
-    my @command_info = (
-        +{
-            command => 'help',
-            summary => 'Show help (this)',
-        },
-        +{
-            command => 'version',
-            summary => 'Show server version',
-        },
-        +{
-            command => 'quit',
-            summary => 'Exit',
-        },
-        +{
-            command => 'display',
-            summary => 'Display slabs info',
-        },
-        +{
-            command => 'stats',
-            summary => 'Show stats',
-            description => <<'EODESC',
-Usage:
-    > stats [<REGEXP>]
-    > stats            # show all stats
-    > stats (hit|miss) # filter by REGEXP
-EODESC
-        },
-        +{
-            command => 'settings',
-            summary => 'Show settings',
-            description => <<'EODESC',
-Usage:
-    > settings [<REGEXP>]
-    > settings             # show all stats
-    > settings ^(lru|slab) # filter by REGEXP
-EODESC
-        },
-        +{
-            command => 'cachedump',
-            summary => 'Show cachedump of specified slab',
-            description => <<'EODESC',
-Usage:
-    > cachedump <CLASS> [<NUMBER>]
-    > cachedump 1 10
-    > cachedump 3     # show default number of items
-EODESC
-        },
-        +{
-            command => 'detaildump',
-            summary => 'Show detail dump',
-            description => <<'EODESC',
-Description:
-    Report statistics about data access using KEY prefix. The default separator
-    for prefix is ':'.
-    If you have not enabled reporting at Memcached start-up, run "detail on".
-    See man memcached(1) for details.
-EODESC
-        },
-        +{
-            command => 'detail',
-            summary => 'Enable/Disable detail dump',
-            description => <<'EODESC',
-Usage:
-    > detail on
-    > detail off
+    my @command_info = @App::Memcached::CLI::Help::COMMANDS_INFO;
 
-Description:
-    See "\h detaildump"
-EODESC
-        },
-        +{
-            command => 'get',
-            summary => 'Get data by KEY',
-            description => <<'EODESC',
-Usage:
-    > get <KEY>
-EODESC
-        },
-        +{
-            command => 'set',
-            summary => 'Set data by KEY VALUE',
-            description => <<'EODESC',
-Usage:
-    > set <KEY> <VALUE> [<EXPIRE> [<FLAGS>]]
-    > set mykey1 MyValue1
-    > set mykey2 MyValue2 0     # Never expires. Default
-    > set mykey3 MyValue3 120 1
-EODESC
-        },
-        +{
-            command => 'delete',
-            summary => 'Delete data by KEY',
-            description => <<'EODESC',
-Usage:
-    > delete <KEY>
-EODESC
-        },
-        +{
-            command => 'flush_all',
-            summary => 'Invalidate whole data',
-            description => <<'EODESC',
-Usage:
-    > flush_all [<DELAY>]
-    > flush_all           # Invalidate immediately
-    > flush_all 60        # Invalidate after 60 seconds
-EODESC
-        },
-    );
     my $body   = q{};
     my $space  = ' ' x 4;
 
@@ -302,7 +201,8 @@ EODESC
     for my $info (@command_info) {
         my $cmd = $info->{command};
         my $commands = join(q{, }, _sorted_aliases_of($cmd));
-        $body .= sprintf "%-24s%s%s\n", $commands, $space, $info->{summary};
+        $body .= sprintf "%s%-20s%s%s\n",
+            $space, $commands, $space x 2, $info->{summary};
     }
     $body .= "\nType \\h <command> for each.\n\n";
     print $body;
@@ -332,8 +232,15 @@ sub get {
     return 1;
 }
 
-sub set {
-    my $self = shift;
+sub set     { return &_store(shift, 'set', @_); }
+sub add     { return &_store(shift, 'add', @_); }
+sub replace { return &_store(shift, 'replace', @_); }
+sub append  { return &_store(shift, 'append',  @_); }
+sub prepend { return &_store(shift, 'prepend', @_); }
+
+sub _store {
+    my $self    = shift;
+    my $command = shift;
     my ($key, $value, $expire, $flags) = @_;
     unless ($key and $value) {
         print "KEY or VALUE not specified.\n";
@@ -345,9 +252,9 @@ sub set {
         expire => $expire,
         flags  => $flags,
     );
-    unless ($item->save($self->{ds})) {
-        warn "Failed to store item. KEY $key, VALUE $value";
-        return;
+    unless ($item->save($self->{ds}, command => $command)) {
+        print "Failed to $command item. KEY $key, VALUE $value\n";
+        return 1;
     }
     print "OK\n";
     return 1;
